@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin Captcha PHP Backend
   * Copyright (c) 2002-2007 milky <http_from3.20.mario17@spamgourmet.org>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -134,8 +134,9 @@ function captcha_php_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function captcha_php_validate_captcha()
@@ -144,7 +145,6 @@ function captcha_php_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_hash', $captcha_hash, SQ_SESSION)
     || empty($captcha_hash))
       return FALSE;
@@ -156,6 +156,12 @@ function captcha_php_validate_captcha()
    sqsession_unregister('captcha_hash');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return $captcha_hash == captcha::hash($captcha_response);
 
 }
