@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin CaptchaSecurityImages Backend
   * Copyright (c) 2006-2007 Simon Jarvis
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -118,8 +118,9 @@ function csi_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function csi_validate_captcha()
@@ -128,7 +129,6 @@ function csi_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('security_code', $security_code, SQ_SESSION)
     || empty($security_code))
       return FALSE;
@@ -137,6 +137,12 @@ function csi_validate_captcha()
    sqsession_unregister('security_code');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return $security_code == $captcha_response;
 
 }
