@@ -648,7 +648,7 @@ class b2evo_captcha
 		{
 			if(is_file($filename) ? TRUE : touch($filename))
 			{
-				if(is_readable($filename) && is_writable($filename))
+				if(is_readable($filename) && sq_is_writable($filename))
 				{
 					$fp = @fopen($filename, 'r');
 					if($fp)
