@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin HN Captcha Backend
   * Copyright (c) 2006-2007 Horst Nogajski <horst@nogajski.de>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -53,7 +53,7 @@ function hn_captcha_show_input_widgets()
    require_once(SM_PATH . 'plugins/captcha/backends/hn_captcha/hn_captcha.class.x1.php');
 
 
-   $captcha =& new hn_captcha_X1(array(
+   $captcha = new hn_captcha_X1(array(
        'tempfolder' => $captcha_temp_folder,
        'TTF_folder' => $captcha_TTF_folder,
        'TTF_RANGE' => $captcha_fonts,
@@ -155,8 +155,9 @@ function hn_captcha_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function hn_captcha_validate_captcha()
@@ -164,8 +165,7 @@ function hn_captcha_validate_captcha()
 
    // just bail if insufficient input is received
    //
-   if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response))
+   if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM))
       return FALSE;
 
 
@@ -183,7 +183,7 @@ function hn_captcha_validate_captcha()
    require_once(SM_PATH . 'plugins/captcha/backends/hn_captcha/hn_captcha.class.x1.php');
 
 
-   $captcha =& new hn_captcha_X1(array(
+   $captcha = new hn_captcha_X1(array(
        'tempfolder' => $captcha_temp_folder,
        'TTF_folder' => $captcha_TTF_folder,
        'TTF_RANGE' => $captcha_fonts,
@@ -210,6 +210,12 @@ function hn_captcha_validate_captcha()
    sqsession_unregister('captcha_public_key');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return $captcha->validate_submit() === 1;
 
 }
