@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin OpenCaptcha Backend
   * Copyright (c) 2007 Christopher Craig <chris@chriscraig.net>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -105,8 +105,9 @@ function opencaptcha_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function opencaptcha_validate_captcha()
@@ -115,7 +116,6 @@ function opencaptcha_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_code', $captcha_code, SQ_SESSION)
     || empty($captcha_code))
       return FALSE;
@@ -131,6 +131,13 @@ function opencaptcha_validate_captcha()
       $captcha_code = strtoupper($captcha_code);
    }
 
+
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return $captcha_response == $captcha_code;
 
 }
