@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin QuickCaptcha Backend
   * Copyright (c) 2006-2007 Web 1 Marketing, Inc.
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -105,8 +105,9 @@ function quickcaptcha_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function quickcaptcha_validate_captcha()
@@ -115,7 +116,6 @@ function quickcaptcha_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_private_string', $captcha_private_string, SQ_SESSION)
     || empty($captcha_private_string))
       return FALSE;
@@ -124,6 +124,12 @@ function quickcaptcha_validate_captcha()
    sqsession_unregister('captcha_private_string');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return strtoupper($captcha_response) == strtoupper($captcha_private_string);
 
 }
