@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin HTML_QuickForm_CAPTCHA Backend
   * Copyright (c) 2006-2007 Philippe Jausions <Philippe.Jausions@11abacus.com>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -27,7 +27,7 @@
 
 
    if (!@include_once(SM_PATH . 'plugins/captcha/backends/quickform/quickform_config.php'))
-      include_once(SM_PATH . 'plugins/captcha/backends/quickform/quickform_config.sample.php');
+      include_once(SM_PATH . 'plugins/captcha/backends/quickform/quickform_config_default.php');
 
 
    require_once('HTML/QuickForm.php');
