@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin HTML_QuickForm_CAPTCHA Backend
   * Copyright (c) 2006-2007 Philippe Jausions <Philippe.Jausions@11abacus.com>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -51,7 +51,7 @@ function quickform_show_input_widgets()
       //
       include_once(SM_PATH . 'functions/strings.php');
 
-      sq_mt_randomize();
+      if (!check_sm_version(1, 5, 2)) sq_mt_randomize();
       $challenge_type = mt_rand(1, 4);
    }
 
@@ -290,8 +290,9 @@ function quickform_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function quickform_validate_captcha()
@@ -300,7 +301,6 @@ function quickform_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_code', $captcha_code, SQ_SESSION)
     || empty($captcha_code))
       return FALSE;
@@ -310,6 +310,12 @@ function quickform_validate_captcha()
    sqsession_unregister('captcha_object');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return strtoupper($captcha_response) == strtoupper($captcha_code);
 
 }
