@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin Text_CAPTCHA_Numeral Backend
   * Copyright (c) 1998-2007 David Coallier <davidc@agoraproduction.com>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -110,8 +110,9 @@ function textcapnum_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function textcapnum_validate_captcha()
@@ -120,7 +121,6 @@ function textcapnum_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_answer', $captcha_answer, SQ_SESSION)
     || empty($captcha_answer))
       return FALSE;
@@ -129,6 +129,12 @@ function textcapnum_validate_captcha()
    sqsession_unregister('captcha_answer');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return $captcha_response == $captcha_answer;
 
 }
