@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail CAPTCHA Plugin Text_CAPTCHA Backend
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -23,7 +23,7 @@ else
 
 
 if (!@include_once(SM_PATH . 'plugins/captcha/backends/textcaptcha/textcaptcha_config.php'))
-   include_once(SM_PATH . 'plugins/captcha/backends/textcaptcha/textcaptcha_config.sample.php');
+   include_once(SM_PATH . 'plugins/captcha/backends/textcaptcha/textcaptcha_config_default.php');
 
 
 
