@@ -4,7 +4,7 @@
   * SquirrelMail CAPTCHA Plugin WaterCap Captcha Backend
   * Copyright (c) 2006-2007 Simon Jarvis
   * Copyright (c) 2007 Pavel Simakov
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -106,8 +106,9 @@ function watercap_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function watercap_validate_captcha()
@@ -116,7 +117,6 @@ function watercap_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_code', $captcha_code, SQ_SESSION)
     || empty($captcha_code))
       return FALSE;
@@ -125,6 +125,12 @@ function watercap_validate_captcha()
    sqsession_unregister('captcha_code');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return strtoupper($captcha_response) == strtoupper($captcha_code);
 
 }
